@@ -40,6 +40,7 @@ class Bump:
                     "prerelease",
                     "increment",
                     "bump_message",
+                    "gpg_sign",
                     "annotated_tag",
                 ]
                 if arguments[key] is not None
@@ -231,6 +232,8 @@ class Bump:
             raise BumpCommitFailedError(f'2nd git.commit error: "{c.err.strip()}"')
         c = git.tag(
             new_tag_version,
+            signed=self.bump_settings.get("gpg_sign", False)
+            or bool(self.config.settings.get("gpg_sign", False)),
             annotated=self.bump_settings.get("annotated_tag", False)
             or bool(self.config.settings.get("annotated_tag", False)),
         )
